@@ -4,7 +4,7 @@
 ;; Author: J.D. Smith <jdtsmith+elpa@gmail.com>
 ;; Homepage: https://github.com/jdtsmith/indent-bars
 ;; Package-Requires: ((emacs "27.1") (compat "30"))
-;; Version: 0.9.1
+;; Version: 0.9.2
 ;; Keywords: convenience
 
 ;; indent-bars is free software: you can redistribute it and/or
@@ -1601,7 +1601,8 @@ Adapted from `highlight-indentation-mode'."
     gpr-ts-mode-indent-offset)
    ((and (derived-mode-p 'python-mode) (boundp 'py-indent-offset))
     py-indent-offset)
-   ((and (derived-mode-p 'python-mode 'python-base-mode) (boundp 'python-indent-offset))
+   ((and (derived-mode-p 'python-mode 'python-base-mode)
+	 (boundp 'python-indent-offset))
     python-indent-offset)
    ((and (derived-mode-p 'ruby-mode) (boundp 'ruby-indent-level))
     ruby-indent-level)
@@ -1624,7 +1625,8 @@ Adapted from `highlight-indentation-mode'."
     js-indent-level)
    ((and (derived-mode-p 'js2-mode) (boundp 'js2-basic-offset))
     js2-basic-offset)
-   ((and (derived-mode-p 'typescript-ts-mode) (boundp 'typescript-ts-mode-indent-offset))
+   ((and (derived-mode-p 'typescript-ts-base-mode)
+	 (boundp 'typescript-ts-mode-indent-offset))
     typescript-ts-mode-indent-offset)
    ((and (derived-mode-p 'sws-mode) (boundp 'sws-tab-width))
     sws-tab-width)
@@ -1638,10 +1640,13 @@ Adapted from `highlight-indentation-mode'."
 	 (symbolp c-ts-common-indent-offset)
 	 (numberp (symbol-value c-ts-common-indent-offset)))
     (symbol-value c-ts-common-indent-offset))
+   ((and (derived-mode-p 'yaml-pro-mode) (boundp 'yaml-pro-indent)
+	 yaml-pro-indent)
+    yaml-pro-indent)
+   ((and (derived-mode-p 'yaml-pro-ts-mode) (boundp 'yaml-pro-ts-indent))
+    yaml-pro-ts-indent)
    ((and (derived-mode-p 'yaml-mode) (boundp 'yaml-indent-offset))
     yaml-indent-offset)
-   ((and (derived-mode-p 'yaml-pro-mode) (boundp 'yaml-pro-indent))
-    yaml-pro-indent)
    ((and (derived-mode-p 'elixir-mode) (boundp 'elixir-smie-indent-basic))
     elixir-smie-indent-basic)
    ((and (derived-mode-p 'lisp-data-mode) (boundp 'lisp-body-indent))
